# Licensed under a 3-clause BSD style license, see LICENSE.
"""
********************
Common unit prefixes
********************

There are 2 types of prefixes:

  * SI prefixes [SI_prefixes]_.
  * Binary prefixes [Binary_prefixes]_.

**References**

.. [SI_prefixes] https://en.wikipedia.org/wiki/International_System_of_Units#Prefixes.
.. [Binary_prefixes] https://en.wikipedia.org/wiki/Unit_prefix#Binary_prefixes.
"""

# -----------------------------------------------------------------------------
# SI prefixes
# -----------------------------------------------------------------------------
yotta = 1.e24
zetta = 1.e21
exa = 1.e18
peta = 1.e15
tera = 1.e12
giga = 1.e9
mega = 1.e6
kilo = 1.e3
hecto = 1.e2
deca = 1.e1
deci = 1.e-1
centi = 1.e-2
milli = 1.e-3
micro = 1.e-6
nano = 1.e-9
pico = 1.e-12
femto = 1.e-15
atto = 1.e-18
zepto = 1.e-21
yocto = 1.e-24

# -----------------------------------------------------------------------------
# Binary prefixes
# -----------------------------------------------------------------------------
kibi = 2. ** 10
mebi = 2. ** 20
gibi = 2. ** 30
tebi = 2. ** 40
pebi = 2. ** 50
exbi = 2. ** 60
zebi = 2. ** 70
yobi = 2. ** 80

# -----------------------------------------------------------------------------
# Miscellaneous prefixes
# -----------------------------------------------------------------------------
googol = 1.e100
